# Changelog

## [0.1.1](https://github.com/imnotjames/pyawful/compare/v0.1.0...v0.1.1) (2024-12-08)


### Bug Fixes

* proper forum thread sort ([c31e385](https://github.com/imnotjames/pyawful/commit/c31e3850e7a30820a1e5a3c7e1cc274e5a197aa1))

## [0.1.0](https://github.com/imnotjames/pyawful/compare/v0.0.1...v0.1.0) (2024-12-07)


### Features

* add SAD abbrev ([cb2bfa1](https://github.com/imnotjames/pyawful/commit/cb2bfa1741e944db2e19e1479e1f1b8e98316abf))
* initial commit of the somethingawful library ([9f0a373](https://github.com/imnotjames/pyawful/commit/9f0a3736874ef18062c64f1abee08a40027a6b65))


### Bug Fixes

* drop registration date from user so we can reference them more ([6e3f0e6](https://github.com/imnotjames/pyawful/commit/6e3f0e6095876b8e8eeb20cfc924345c9028efbe))


### Documentation

* add example usage to readme ([ba7fb6a](https://github.com/imnotjames/pyawful/commit/ba7fb6ad7df08f32776312c2d132cbbb1972dc43))
